### RedVox Python SDK

![Build Status](https://github.com/RedVoxInc/redvox-python-sdk/actions/workflows/testing.yml/badge.svg)

This repository contains code for reading and working with the RedVox API 900 and API 1000 (M) data formats.

* [User Documentation](https://github.com/RedVoxInc/redvox-python-sdk/tree/master/docs/python_sdk)
* [API Documentation](https://redvoxinc.github.io/redvox-sdk/api_docs/redvox/index.html)
* [Changelog](https://github.com/RedVoxInc/redvox-python-sdk/tree/master/docs/changelog.md)